/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __SCREEN_CONNECTOR_WATCHER_H__
#define __SCREEN_CONNECTOR_WATCHER_H__

#include <wayland-client.h>
#include <wayland-tbm-client.h>
#ifdef __cplusplus
extern "C" {
#endif

typedef void (*screen_connector_watcher_added_cb)(const char *appid, const char *instance_id, const int pid, void *data);
typedef void (*screen_connector_watcher_removed_cb)(const char *appid, const char *instance_id, const int pid, void *data);
typedef void (*screen_connector_watcher_update_cb)(struct tizen_remote_surface *trs, uint32_t type, struct wl_buffer *tbm,
		int32_t img_file_fd, uint32_t img_file_size, uint32_t time, struct wl_array *keys,
		const char *appid, const char *instance_id, const int pid,void *data);

typedef struct _screen_connector_watcher_ops {
	screen_connector_watcher_added_cb added_cb;
	screen_connector_watcher_removed_cb removed_cb;
	screen_connector_watcher_update_cb updated_cb;
} screen_connector_watcher_ops;

typedef struct _screen_connector_watcher_h *screen_connector_watcher_h;
typedef struct _screen_connector_info_h *screen_connector_info_h;

int screen_connector_watcher_init(void);
int screen_connector_watcher_fini(void);
screen_connector_watcher_h screen_connector_watcher_add(screen_connector_watcher_ops *ops, void *data);
int screen_connector_watcher_remove(screen_connector_watcher_h h);
int screen_connector_watcher_update(screen_connector_watcher_h h, const char *instance_id);
char *screen_connector_watcher_get_appid(screen_connector_info_h h);
char *screen_connector_watcher_get_instance_id(screen_connector_info_h h);
int screen_connector_watcher_get_pid(screen_connector_info_h h);
int screen_connector_watcher_get_surface_id(screen_connector_info_h h);
void *screen_connector_watcher_get_user_data(screen_connector_info_h h);

int screen_connector_watcher_set_resource_id(screen_connector_watcher_h h, int rid);
struct tizen_remote_surface *screen_connector_watcher_get_trs(screen_connector_watcher_h h);
screen_connector_watcher_h screen_connector_watcher_create_handle(char *id, int pid, screen_connector_watcher_ops *ops, void *data);
int screen_connector_watcher_redirect_surface(screen_connector_info_h info);

#ifdef __cplusplus
}
#endif

#endif /* __SCREEN_CONNECTOR_WATCHER_H__ */
